@@ -2,13 +2,20 @@ from langchain_community.document_loaders import DirectoryLoader
 from ai_assistant.llm_cli import openai_client
 from ai_assistant.prompt_llm import AIAssistant
 from ai_assistant.consts import COMMANDS
+from yaspin import yaspin
+
+
 DATA_PATH = "./documents"
 
 
-
+@yaspin(text="Generating documentation...")
 def generate_data_store():
+    loader = yaspin()
+    loader.start()
     code = get_code()
     result = prompt(code)
+    loader.stop()
+    
     return result
 
 
